/*
** Style sheet for makepp
** Daniel Pfeiffer <occitan@esperanto.org>
** $Id: makepp.css,v 1.10 2011/08/06 11:47:22 pfeiffer Exp $
*/

body {
  background-color: white;
  color: black;
}

table#Nav {
  float: right;
}

table#Nav th {
  font-size: 70%;
}

table#Nav td {
  font-size: 70%;
  margin: 10px;
  padding: 10px;
  background: url(pre.png) repeat-y;
}

h1, h2, h3, .makepp {
  color: #0090e0;
}

b {
  color: #222;
}

a b, h1 b, h2 b, h3 b {
  color: inherit;
}

pre {
  background: url(pre.png) repeat-y;
  padding: 10px 10px 10px;
}

hr {
  width: 33%;
  margin-right: 67%;
}

dt {
  font-weight: bold;
}

.comment { color: brown; font: sans-serif }

.tall {
  font-size: 180%;
  vertical-align: text-bottom;
}

address {
  text-align: right;
}
